@@ -5,7 +5,7 @@ package OpenAPI::Modern;
 # ABSTRACT: Validate HTTP requests and responses against an OpenAPI document
 # KEYWORDS: validation evaluation JSON Schema OpenAPI Swagger HTTP request response
 
-our $VERSION = '0.007';
+our $VERSION = '0.008';
 
 use 5.020;  # for fc, unicode_strings features
 use Moo;
@@ -18,9 +18,8 @@ no if "$]" >= 5.033006, feature => 'bareword_filehandles';
 use Carp 'croak';
 use Safe::Isa;
 use Ref::Util qw(is_plain_hashref is_plain_arrayref is_ref);
-use List::Util 1.45 qw(first uniq);
+use List::Util 'first';
 use Scalar::Util 'looks_like_number';
-use Module::Runtime 'require_module';
 use Feature::Compat::Try;
 use JSON::Schema::Modern 0.527;
 use JSON::Schema::Modern::Utilities qw(jsonp canonical_uri E abort);
@@ -49,10 +48,6 @@ has evaluator => (
   handles => [ qw(get_media_type add_media_type) ],
 );
 
-sub load_vocabulary_classes ($self) {
-  require_module($_) foreach uniq map $_->{vocabularies}->@*, $self->evaluator->_resource_values;
-}
-
 around BUILDARGS => sub ($orig, $class, @args) {
   my $args = $class->$orig(@args);
 
@@ -216,7 +211,7 @@ sub validate_response ($self, $response, $options) {
       $response_obj = $self->_resolve_ref($ref, $state);
     }
 
-    foreach my $header_name (keys(($response_obj->{headers}//{})->%*)) {
+    foreach my $header_name (sort keys(($response_obj->{headers}//{})->%*)) {
       next if fc $header_name eq fc 'Content-Type';
       my $state = { %$state, schema_path => jsonp($state->{schema_path}, 'headers', $header_name) };
       my $header_obj = $response_obj->{headers}{$header_name};
@@ -335,7 +330,7 @@ sub _validate_body_content ($self, $state, $content_obj, $message) {
   if (exists $content_obj->{$content_type}{encoding}) {
     my $state = { %$state, schema_path => jsonp($state->{schema_path}, 'content', $content_type) };
     # "The key, being the property name, MUST exist in the schema as a property."
-    foreach my $property (keys $content_obj->{$content_type}{encoding}->%*) {
+    foreach my $property (sort keys $content_obj->{$content_type}{encoding}->%*) {
       ()= E({ $state, schema_path => jsonp($state->{schema_path}, 'schema', 'properties', $property) },
           'encoding property "%s" requires a matching property definition in the schema')
         if not exists(($content_obj->{$content_type}{schema}{properties}//{})->{$property});
@@ -450,7 +445,7 @@ OpenAPI::Modern - Validate HTTP requests and responses against an OpenAPI docume
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 SYNOPSIS
 
@@ -636,12 +631,6 @@ C<path_template>: a string representing the request URI, with placeholders in br
 
 More options will be added later, providing more flexible matching of the document to the request.
 
-=head2 load_vocabulary_classes
-
-Loads all vocabulary classes found within the resource index of the JSON Schema evaluator.
-Useful when deserializing an object from disk (where resource data exists in memory but the
-corresponding implementations are no longer loaded.
-
 =head1 ON THE USE OF JSON SCHEMAS
 
 Embedded JSON Schemas, through the use of the C<schema> keyword, are fully draft2020-12-compliant,
